/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED! */
#ifndef __ATOMICS_SKEL_H__
#define __ATOMICS_SKEL_H__

#include <stdlib.h>
#include <bpf/libbpf.h>

struct atomics {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *data;
		struct bpf_map *bss;
	} maps;
	struct {
		struct bpf_program *add;
		struct bpf_program *sub;
		struct bpf_program *and;
		struct bpf_program *or;
		struct bpf_program *xor;
		struct bpf_program *cmpxchg;
		struct bpf_program *xchg;
	} progs;
	struct {
		struct bpf_link *add;
		struct bpf_link *sub;
		struct bpf_link *and;
		struct bpf_link *or;
		struct bpf_link *xor;
		struct bpf_link *cmpxchg;
		struct bpf_link *xchg;
	} links;
	struct atomics__data {
		_Bool skip_tests;
		char __pad0[7];
		__u64 add64_value;
		__u32 add32_value;
		char __pad1[4];
		__u64 add_noreturn_value;
		__s64 sub64_value;
		__s32 sub32_value;
		char __pad2[4];
		__s64 sub_noreturn_value;
		__u64 and64_value;
		__u32 and32_value;
		char __pad3[4];
		__u64 and_noreturn_value;
		__u64 or64_value;
		__u32 or32_value;
		char __pad4[4];
		__u64 or_noreturn_value;
		__u64 xor64_value;
		__u32 xor32_value;
		char __pad5[4];
		__u64 xor_noreturn_value;
		__u64 cmpxchg64_value;
		__u32 cmpxchg32_value;
		char __pad6[4];
		__u64 xchg64_value;
		__u32 xchg32_value;
	} *data;
	struct atomics__bss {
		__u64 add64_result;
		__u32 add32_result;
		char __pad0[4];
		__u64 add_stack_value_copy;
		__u64 add_stack_result;
		__s64 sub64_result;
		__s32 sub32_result;
		char __pad1[4];
		__s64 sub_stack_value_copy;
		__s64 sub_stack_result;
		__u64 and64_result;
		__u32 and32_result;
		char __pad2[4];
		__u64 or64_result;
		__u32 or32_result;
		char __pad3[4];
		__u64 xor64_result;
		__u32 xor32_result;
		char __pad4[4];
		__u64 cmpxchg64_result_fail;
		__u64 cmpxchg64_result_succeed;
		__u32 cmpxchg32_result_fail;
		__u32 cmpxchg32_result_succeed;
		__u64 xchg64_result;
		__u32 xchg32_result;
	} *bss;
};

static void
atomics__destroy(struct atomics *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
atomics__create_skeleton(struct atomics *obj);

static inline struct atomics *
atomics__open_opts(const struct bpf_object_open_opts *opts)
{
	struct atomics *obj;

	obj = (struct atomics *)calloc(1, sizeof(*obj));
	if (!obj)
		return NULL;
	if (atomics__create_skeleton(obj))
		goto err;
	if (bpf_object__open_skeleton(obj->skeleton, opts))
		goto err;

	return obj;
err:
	atomics__destroy(obj);
	return NULL;
}

static inline struct atomics *
atomics__open(void)
{
	return atomics__open_opts(NULL);
}

static inline int
atomics__load(struct atomics *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct atomics *
atomics__open_and_load(void)
{
	struct atomics *obj;

	obj = atomics__open();
	if (!obj)
		return NULL;
	if (atomics__load(obj)) {
		atomics__destroy(obj);
		return NULL;
	}
	return obj;
}

static inline int
atomics__attach(struct atomics *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
atomics__detach(struct atomics *obj)
{
	return bpf_object__detach_skeleton(obj->skeleton);
}

static inline int
atomics__create_skeleton(struct atomics *obj)
{
	struct bpf_object_skeleton *s;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)
		return -1;
	obj->skeleton = s;

	s->sz = sizeof(*s);
	s->name = "atomics";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 2;
	s->map_skel_sz = sizeof(*s->maps);
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt, s->map_skel_sz);
	if (!s->maps)
		goto err;

	s->maps[0].name = "atomics.data";
	s->maps[0].map = &obj->maps.data;
	s->maps[0].mmaped = (void **)&obj->data;

	s->maps[1].name = "atomics.bss";
	s->maps[1].map = &obj->maps.bss;
	s->maps[1].mmaped = (void **)&obj->bss;

	/* programs */
	s->prog_cnt = 7;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs)
		goto err;

	s->progs[0].name = "add";
	s->progs[0].prog = &obj->progs.add;
	s->progs[0].link = &obj->links.add;

	s->progs[1].name = "sub";
	s->progs[1].prog = &obj->progs.sub;
	s->progs[1].link = &obj->links.sub;

	s->progs[2].name = "and";
	s->progs[2].prog = &obj->progs.and;
	s->progs[2].link = &obj->links.and;

	s->progs[3].name = "or";
	s->progs[3].prog = &obj->progs.or;
	s->progs[3].link = &obj->links.or;

	s->progs[4].name = "xor";
	s->progs[4].prog = &obj->progs.xor;
	s->progs[4].link = &obj->links.xor;

	s->progs[5].name = "cmpxchg";
	s->progs[5].prog = &obj->progs.cmpxchg;
	s->progs[5].link = &obj->links.cmpxchg;

	s->progs[6].name = "xchg";
	s->progs[6].prog = &obj->progs.xchg;
	s->progs[6].link = &obj->links.xchg;

	s->data_sz = 9952;
	s->data = (void *)"\
\x7f\x45\x4c\x46\x02\x01\x01\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\x01\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\xa0\x24\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x09\0\
\x01\0\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x66\x65\
\x6e\x74\x72\x79\x2f\x62\x70\x66\x5f\x66\x65\x6e\x74\x72\x79\x5f\x74\x65\x73\
\x74\x31\0\x2e\x64\x61\x74\x61\0\x2e\x62\x73\x73\0\x61\x74\x6f\x6d\x69\x63\x73\
\x2e\x63\0\x61\x64\x64\0\x61\x64\x64\x36\x34\x5f\x76\x61\x6c\x75\x65\0\x61\x64\
\x64\x36\x34\x5f\x72\x65\x73\x75\x6c\x74\0\x61\x64\x64\x33\x32\x5f\x76\x61\x6c\
\x75\x65\0\x61\x64\x64\x33\x32\x5f\x72\x65\x73\x75\x6c\x74\0\x61\x64\x64\x5f\
\x73\x74\x61\x63\x6b\x5f\x72\x65\x73\x75\x6c\x74\0\x61\x64\x64\x5f\x73\x74\x61\
\x63\x6b\x5f\x76\x61\x6c\x75\x65\x5f\x63\x6f\x70\x79\0\x61\x64\x64\x5f\x6e\x6f\
\x72\x65\x74\x75\x72\x6e\x5f\x76\x61\x6c\x75\x65\0\x73\x75\x62\0\x73\x75\x62\
\x36\x34\x5f\x76\x61\x6c\x75\x65\0\x73\x75\x62\x36\x34\x5f\x72\x65\x73\x75\x6c\
\x74\0\x73\x75\x62\x33\x32\x5f\x76\x61\x6c\x75\x65\0\x73\x75\x62\x33\x32\x5f\
\x72\x65\x73\x75\x6c\x74\0\x73\x75\x62\x5f\x73\x74\x61\x63\x6b\x5f\x72\x65\x73\
\x75\x6c\x74\0\x73\x75\x62\x5f\x73\x74\x61\x63\x6b\x5f\x76\x61\x6c\x75\x65\x5f\
\x63\x6f\x70\x79\0\x73\x75\x62\x5f\x6e\x6f\x72\x65\x74\x75\x72\x6e\x5f\x76\x61\
\x6c\x75\x65\0\x61\x6e\x64\0\x61\x6e\x64\x36\x34\x5f\x76\x61\x6c\x75\x65\0\x61\
\x6e\x64\x36\x34\x5f\x72\x65\x73\x75\x6c\x74\0\x61\x6e\x64\x33\x32\x5f\x76\x61\
\x6c\x75\x65\0\x61\x6e\x64\x33\x32\x5f\x72\x65\x73\x75\x6c\x74\0\x61\x6e\x64\
\x5f\x6e\x6f\x72\x65\x74\x75\x72\x6e\x5f\x76\x61\x6c\x75\x65\0\x6f\x72\0\x6f\
\x72\x36\x34\x5f\x76\x61\x6c\x75\x65\0\x6f\x72\x36\x34\x5f\x72\x65\x73\x75\x6c\
\x74\0\x6f\x72\x33\x32\x5f\x76\x61\x6c\x75\x65\0\x6f\x72\x33\x32\x5f\x72\x65\
\x73\x75\x6c\x74\0\x6f\x72\x5f\x6e\x6f\x72\x65\x74\x75\x72\x6e\x5f\x76\x61\x6c\
\x75\x65\0\x78\x6f\x72\0\x78\x6f\x72\x36\x34\x5f\x76\x61\x6c\x75\x65\0\x78\x6f\
\x72\x36\x34\x5f\x72\x65\x73\x75\x6c\x74\0\x78\x6f\x72\x33\x32\x5f\x76\x61\x6c\
\x75\x65\0\x78\x6f\x72\x33\x32\x5f\x72\x65\x73\x75\x6c\x74\0\x78\x6f\x72\x5f\
\x6e\x6f\x72\x65\x74\x75\x72\x6e\x5f\x76\x61\x6c\x75\x65\0\x63\x6d\x70\x78\x63\
\x68\x67\0\x63\x6d\x70\x78\x63\x68\x67\x36\x34\x5f\x76\x61\x6c\x75\x65\0\x63\
\x6d\x70\x78\x63\x68\x67\x36\x34\x5f\x72\x65\x73\x75\x6c\x74\x5f\x66\x61\x69\
\x6c\0\x63\x6d\x70\x78\x63\x68\x67\x36\x34\x5f\x72\x65\x73\x75\x6c\x74\x5f\x73\
\x75\x63\x63\x65\x65\x64\0\x63\x6d\x70\x78\x63\x68\x67\x33\x32\x5f\x76\x61\x6c\
\x75\x65\0\x63\x6d\x70\x78\x63\x68\x67\x33\x32\x5f\x72\x65\x73\x75\x6c\x74\x5f\
\x66\x61\x69\x6c\0\x63\x6d\x70\x78\x63\x68\x67\x33\x32\x5f\x72\x65\x73\x75\x6c\
\x74\x5f\x73\x75\x63\x63\x65\x65\x64\0\x78\x63\x68\x67\0\x78\x63\x68\x67\x36\
\x34\x5f\x76\x61\x6c\x75\x65\0\x78\x63\x68\x67\x36\x34\x5f\x72\x65\x73\x75\x6c\
\x74\0\x78\x63\x68\x67\x33\x32\x5f\x76\x61\x6c\x75\x65\0\x78\x63\x68\x67\x33\
\x32\x5f\x72\x65\x73\x75\x6c\x74\0\x73\x6b\x69\x70\x5f\x74\x65\x73\x74\x73\0\
\x2e\x72\x65\x6c\x66\x65\x6e\x74\x72\x79\x2f\x62\x70\x66\x5f\x66\x65\x6e\x74\
\x72\x79\x5f\x74\x65\x73\x74\x31\0\x2e\x42\x54\x46\0\x2e\x42\x54\x46\x2e\x65\
\x78\x74\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x34\0\0\0\x04\0\
\xf1\xff\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x03\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x3e\0\0\0\x12\0\x03\0\0\0\0\0\0\0\0\0\xf8\0\0\0\0\0\0\0\x42\0\0\
\0\x11\0\x04\0\x08\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x4e\0\0\0\x11\0\x05\0\0\0\0\
\0\0\0\0\0\x08\0\0\0\0\0\0\0\x5b\0\0\0\x11\0\x04\0\x10\0\0\0\0\0\0\0\x04\0\0\0\
\0\0\0\0\x67\0\0\0\x11\0\x05\0\x08\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x74\0\0\0\
\x11\0\x05\0\x18\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x85\0\0\0\x11\0\x05\0\x10\0\0\
\0\0\0\0\0\x08\0\0\0\0\0\0\0\x9a\0\0\0\x11\0\x04\0\x18\0\0\0\0\0\0\0\x08\0\0\0\
\0\0\0\0\xad\0\0\0\x12\0\x03\0\xf8\0\0\0\0\0\0\0\x08\x01\0\0\0\0\0\0\xb1\0\0\0\
\x11\0\x04\0\x20\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\xbd\0\0\0\x11\0\x05\0\x20\0\0\
\0\0\0\0\0\x08\0\0\0\0\0\0\0\xca\0\0\0\x11\0\x04\0\x28\0\0\0\0\0\0\0\x04\0\0\0\
\0\0\0\0\xd6\0\0\0\x11\0\x05\0\x28\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\xe3\0\0\0\
\x11\0\x05\0\x38\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\xf4\0\0\0\x11\0\x05\0\x30\0\0\
\0\0\0\0\0\x08\0\0\0\0\0\0\0\x09\x01\0\0\x11\0\x04\0\x30\0\0\0\0\0\0\0\x08\0\0\
\0\0\0\0\0\x1c\x01\0\0\x12\0\x03\0\0\x02\0\0\0\0\0\0\xb0\0\0\0\0\0\0\0\x20\x01\
\0\0\x11\0\x04\0\x38\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x2c\x01\0\0\x11\0\x05\0\
\x40\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x39\x01\0\0\x11\0\x04\0\x40\0\0\0\0\0\0\0\
\x04\0\0\0\0\0\0\0\x45\x01\0\0\x11\0\x05\0\x48\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\
\x52\x01\0\0\x11\0\x04\0\x48\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x65\x01\0\0\x12\0\
\x03\0\xb0\x02\0\0\0\0\0\0\xb0\0\0\0\0\0\0\0\x68\x01\0\0\x11\0\x04\0\x50\0\0\0\
\0\0\0\0\x08\0\0\0\0\0\0\0\x73\x01\0\0\x11\0\x05\0\x50\0\0\0\0\0\0\0\x08\0\0\0\
\0\0\0\0\x7f\x01\0\0\x11\0\x04\0\x58\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x8a\x01\0\
\0\x11\0\x05\0\x58\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x96\x01\0\0\x11\0\x04\0\x60\
\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\xa8\x01\0\0\x12\0\x03\0\x60\x03\0\0\0\0\0\0\
\xb0\0\0\0\0\0\0\0\xac\x01\0\0\x11\0\x04\0\x68\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\
\xb8\x01\0\0\x11\0\x05\0\x60\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\xc5\x01\0\0\x11\0\
\x04\0\x70\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\xd1\x01\0\0\x11\0\x05\0\x68\0\0\0\0\
\0\0\0\x04\0\0\0\0\0\0\0\xde\x01\0\0\x11\0\x04\0\x78\0\0\0\0\0\0\0\x08\0\0\0\0\
\0\0\0\xf1\x01\0\0\x12\0\x03\0\x10\x04\0\0\0\0\0\0\xf0\0\0\0\0\0\0\0\xf9\x01\0\
\0\x11\0\x04\0\x80\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x09\x02\0\0\x11\0\x05\0\x70\
\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x1f\x02\0\0\x11\0\x05\0\x78\0\0\0\0\0\0\0\x08\
\0\0\0\0\0\0\0\x38\x02\0\0\x11\0\x04\0\x88\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x48\
\x02\0\0\x11\0\x05\0\x80\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x5e\x02\0\0\x11\0\x05\
\0\x84\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x77\x02\0\0\x12\0\x03\0\0\x05\0\0\0\0\0\
\0\x80\0\0\0\0\0\0\0\x7c\x02\0\0\x11\0\x04\0\x90\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\
\0\x89\x02\0\0\x11\0\x05\0\x88\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x97\x02\0\0\x11\
\0\x04\0\x98\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\xa4\x02\0\0\x11\0\x05\0\x90\0\0\0\
\0\0\0\0\x04\0\0\0\0\0\0\0\xb2\x02\0\0\x11\0\x04\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\
\0\0\0\xb7\x01\0\0\x01\0\0\0\x7b\x1a\xf8\xff\0\0\0\0\xb7\x01\0\0\x02\0\0\0\x18\
\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x03\0\0\x02\0\0\0\xdb\x32\0\0\x01\0\0\0\
\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x7b\x32\0\0\0\0\0\0\xb4\x02\0\0\x02\0\0\0\
\x18\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xc3\x23\0\0\x01\0\0\0\x18\x03\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x63\x23\0\0\0\0\0\0\xb7\x02\0\0\x02\0\0\0\xdb\x2a\xf8\xff\x01\
\0\0\0\x18\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x7b\x23\0\0\0\0\0\0\x18\x02\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x79\xa3\xf8\xff\0\0\0\0\x7b\x32\0\0\0\0\0\0\x18\x02\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\xdb\x12\0\0\0\0\0\0\xb4\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\
\xb7\x01\0\0\x01\0\0\0\x7b\x1a\xf8\xff\0\0\0\0\xb7\x01\0\0\x02\0\0\0\x87\x01\0\
\0\0\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xbf\x13\0\0\0\0\0\0\xdb\x32\0\0\
\x01\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x7b\x32\0\0\0\0\0\0\xb4\x02\0\0\
\x02\0\0\0\x84\x02\0\0\0\0\0\0\x18\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xc3\x23\0\0\
\x01\0\0\0\x18\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x23\0\0\0\0\0\0\xbf\x12\0\0\
\0\0\0\0\xdb\x2a\xf8\xff\x01\0\0\0\x18\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x7b\x23\
\0\0\0\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x79\xa3\xf8\xff\0\0\0\0\x7b\
\x32\0\0\0\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xdb\x12\0\0\0\0\0\0\xb4\0\
\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\x11\0\0\0\x18\x02\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x18\x03\0\0\0\0\0\0\0\0\0\0\x11\0\0\0\xdb\x32\0\0\
\x51\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x7b\x32\0\0\0\0\0\0\xb4\x02\0\0\
\x11\0\0\0\x18\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xc3\x23\0\0\x51\0\0\0\x18\x03\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x23\0\0\0\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\xdb\x12\0\0\x50\0\0\0\xb4\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x18\x01\0\0\0\0\
\0\0\0\0\0\0\x11\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x18\x03\0\0\0\0\0\0\
\0\0\0\0\x11\0\0\0\xdb\x32\0\0\x41\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x7b\x32\0\0\0\0\0\0\xb4\x02\0\0\x11\0\0\0\x18\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\xc3\x23\0\0\x41\0\0\0\x18\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x23\0\0\0\0\0\0\
\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xdb\x12\0\0\x40\0\0\0\xb4\0\0\0\0\0\0\0\
\x95\0\0\0\0\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\x11\0\0\0\x18\x02\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x18\x03\0\0\0\0\0\0\0\0\0\0\x11\0\0\0\xdb\x32\0\0\xa1\0\0\0\x18\
\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x7b\x32\0\0\0\0\0\0\xb4\x02\0\0\x11\0\0\0\x18\
\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xc3\x23\0\0\xa1\0\0\0\x18\x03\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x63\x23\0\0\0\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xdb\x12\0\
\0\xa0\0\0\0\xb4\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\xb7\x01\0\0\x03\0\0\0\x18\x02\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\0\0\0\0\0\0\0\xdb\x12\0\0\xf1\0\0\0\x18\x01\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x7b\x01\0\0\0\0\0\0\xb7\x01\0\0\x02\0\0\0\xb7\0\0\0\
\x01\0\0\0\xdb\x12\0\0\xf1\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x7b\x01\0\
\0\0\0\0\0\xb4\x01\0\0\x03\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb4\0\0\0\
\0\0\0\0\xc3\x12\0\0\xf1\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x01\0\0\
\0\0\0\0\xb4\x01\0\0\x02\0\0\0\xb4\0\0\0\x01\0\0\0\xc3\x12\0\0\xf1\0\0\0\x18\
\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x01\0\0\0\0\0\0\xb4\0\0\0\0\0\0\0\x95\0\0\
\0\0\0\0\0\xb7\x01\0\0\x02\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xdb\x12\0\
\0\xe1\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x7b\x12\0\0\0\0\0\0\xb4\x01\0\
\0\x02\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xc3\x12\0\0\xe1\0\0\0\x18\x02\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x63\x12\0\0\0\0\0\0\xb4\0\0\0\0\0\0\0\x95\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\
\x01\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\x10\x01\0\0\x10\
\x01\0\0\0\0\0\0\0\0\0\0\x10\x01\0\0\0\0\0\0\x10\x01\0\0\x10\x01\0\0\0\0\0\0\0\
\0\0\0\x10\x01\0\0\0\0\0\0\x10\x01\0\0\x10\x01\0\0\0\0\0\0\0\0\0\0\x10\x01\0\0\
\x01\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\x18\0\
\0\0\0\0\0\0\x01\0\0\0\x04\0\0\0\x38\0\0\0\0\0\0\0\x01\0\0\0\x05\0\0\0\x58\0\0\
\0\0\0\0\0\x01\0\0\0\x06\0\0\0\x70\0\0\0\0\0\0\0\x01\0\0\0\x07\0\0\0\x98\0\0\0\
\0\0\0\0\x01\0\0\0\x08\0\0\0\xb0\0\0\0\0\0\0\0\x01\0\0\0\x09\0\0\0\xd0\0\0\0\0\
\0\0\0\x01\0\0\0\x0a\0\0\0\x18\x01\0\0\0\0\0\0\x01\0\0\0\x0c\0\0\0\x38\x01\0\0\
\0\0\0\0\x01\0\0\0\x0d\0\0\0\x60\x01\0\0\0\0\0\0\x01\0\0\0\x0e\0\0\0\x78\x01\0\
\0\0\0\0\0\x01\0\0\0\x0f\0\0\0\xa0\x01\0\0\0\0\0\0\x01\0\0\0\x10\0\0\0\xb8\x01\
\0\0\0\0\0\0\x01\0\0\0\x11\0\0\0\xd8\x01\0\0\0\0\0\0\x01\0\0\0\x12\0\0\0\x10\
\x02\0\0\0\0\0\0\x01\0\0\0\x14\0\0\0\x38\x02\0\0\0\0\0\0\x01\0\0\0\x15\0\0\0\
\x58\x02\0\0\0\0\0\0\x01\0\0\0\x16\0\0\0\x70\x02\0\0\0\0\0\0\x01\0\0\0\x17\0\0\
\0\x88\x02\0\0\0\0\0\0\x01\0\0\0\x18\0\0\0\xc0\x02\0\0\0\0\0\0\x01\0\0\0\x1a\0\
\0\0\xe8\x02\0\0\0\0\0\0\x01\0\0\0\x1b\0\0\0\x08\x03\0\0\0\0\0\0\x01\0\0\0\x1c\
\0\0\0\x20\x03\0\0\0\0\0\0\x01\0\0\0\x1d\0\0\0\x38\x03\0\0\0\0\0\0\x01\0\0\0\
\x1e\0\0\0\x70\x03\0\0\0\0\0\0\x01\0\0\0\x20\0\0\0\x98\x03\0\0\0\0\0\0\x01\0\0\
\0\x21\0\0\0\xb8\x03\0\0\0\0\0\0\x01\0\0\0\x22\0\0\0\xd0\x03\0\0\0\0\0\0\x01\0\
\0\0\x23\0\0\0\xe8\x03\0\0\0\0\0\0\x01\0\0\0\x24\0\0\0\x18\x04\0\0\0\0\0\0\x01\
\0\0\0\x26\0\0\0\x38\x04\0\0\0\0\0\0\x01\0\0\0\x27\0\0\0\x68\x04\0\0\0\0\0\0\
\x01\0\0\0\x28\0\0\0\x88\x04\0\0\0\0\0\0\x01\0\0\0\x29\0\0\0\xa8\x04\0\0\0\0\0\
\0\x01\0\0\0\x2a\0\0\0\xd8\x04\0\0\0\0\0\0\x01\0\0\0\x2b\0\0\0\x08\x05\0\0\0\0\
\0\0\x01\0\0\0\x2d\0\0\0\x20\x05\0\0\0\0\0\0\x01\0\0\0\x2e\0\0\0\x40\x05\0\0\0\
\0\0\0\x01\0\0\0\x2f\0\0\0\x58\x05\0\0\0\0\0\0\x01\0\0\0\x30\0\0\0\x9f\xeb\x01\
\0\x18\0\0\0\0\0\0\0\x6c\x05\0\0\x6c\x05\0\0\x4e\x0a\0\0\0\0\0\0\0\0\0\x02\x02\
\0\0\0\x01\0\0\0\0\0\0\x01\x08\0\0\0\x40\0\0\0\0\0\0\0\x01\0\0\x0d\x04\0\0\0\
\x18\0\0\0\x01\0\0\0\x1c\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\x01\x20\0\0\0\x01\0\
\0\x0c\x03\0\0\0\x24\0\0\0\x01\0\0\x0c\x03\0\0\0\x28\0\0\0\x01\0\0\x0c\x03\0\0\
\0\x2c\0\0\0\x01\0\0\x0c\x03\0\0\0\x2f\0\0\0\x01\0\0\x0c\x03\0\0\0\x33\0\0\0\
\x01\0\0\x0c\x03\0\0\0\x3b\0\0\0\x01\0\0\x0c\x03\0\0\0\x40\0\0\0\0\0\0\x01\x01\
\0\0\0\x08\0\0\x04\x46\0\0\0\0\0\0\x0e\x0c\0\0\0\x01\0\0\0\x51\0\0\0\0\0\0\x08\
\x02\0\0\0\x57\0\0\0\0\0\0\x0e\x0e\0\0\0\x01\0\0\0\x63\0\0\0\0\0\0\x0e\x0e\0\0\
\0\x01\0\0\0\x70\0\0\0\0\0\0\x08\x12\0\0\0\x76\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\
\0\0\x83\0\0\0\0\0\0\x0e\x11\0\0\0\x01\0\0\0\x8f\0\0\0\0\0\0\x0e\x11\0\0\0\x01\
\0\0\0\x9c\0\0\0\0\0\0\x0e\x0e\0\0\0\x01\0\0\0\xb1\0\0\0\0\0\0\x0e\x0e\0\0\0\
\x01\0\0\0\xc2\0\0\0\0\0\0\x0e\x0e\0\0\0\x01\0\0\0\xd5\0\0\0\0\0\0\x08\x19\0\0\
\0\xdb\0\0\0\0\0\0\x01\x08\0\0\0\x40\0\0\x01\xe9\0\0\0\0\0\0\x0e\x18\0\0\0\x01\
\0\0\0\xf5\0\0\0\0\0\0\x0e\x18\0\0\0\x01\0\0\0\x02\x01\0\0\0\0\0\x08\x04\0\0\0\
\x08\x01\0\0\0\0\0\x0e\x1c\0\0\0\x01\0\0\0\x14\x01\0\0\0\0\0\x0e\x1c\0\0\0\x01\
\0\0\0\x21\x01\0\0\0\0\0\x0e\x18\0\0\0\x01\0\0\0\x36\x01\0\0\0\0\0\x0e\x18\0\0\
\0\x01\0\0\0\x47\x01\0\0\0\0\0\x0e\x18\0\0\0\x01\0\0\0\x5a\x01\0\0\0\0\0\x0e\
\x0e\0\0\0\x01\0\0\0\x66\x01\0\0\0\0\0\x0e\x0e\0\0\0\x01\0\0\0\x73\x01\0\0\0\0\
\0\x0e\x11\0\0\0\x01\0\0\0\x7f\x01\0\0\0\0\0\x0e\x11\0\0\0\x01\0\0\0\x8c\x01\0\
\0\0\0\0\x0e\x0e\0\0\0\x01\0\0\0\x9f\x01\0\0\0\0\0\x0e\x0e\0\0\0\x01\0\0\0\xaa\
\x01\0\0\0\0\0\x0e\x0e\0\0\0\x01\0\0\0\xb6\x01\0\0\0\0\0\x0e\x11\0\0\0\x01\0\0\
\0\xc1\x01\0\0\0\0\0\x0e\x11\0\0\0\x01\0\0\0\xcd\x01\0\0\0\0\0\x0e\x0e\0\0\0\
\x01\0\0\0\xdf\x01\0\0\0\0\0\x0e\x0e\0\0\0\x01\0\0\0\xeb\x01\0\0\0\0\0\x0e\x0e\
\0\0\0\x01\0\0\0\xf8\x01\0\0\0\0\0\x0e\x11\0\0\0\x01\0\0\0\x04\x02\0\0\0\0\0\
\x0e\x11\0\0\0\x01\0\0\0\x11\x02\0\0\0\0\0\x0e\x0e\0\0\0\x01\0\0\0\x24\x02\0\0\
\0\0\0\x0e\x0e\0\0\0\x01\0\0\0\x34\x02\0\0\0\0\0\x0e\x0e\0\0\0\x01\0\0\0\x4a\
\x02\0\0\0\0\0\x0e\x0e\0\0\0\x01\0\0\0\x63\x02\0\0\0\0\0\x0e\x11\0\0\0\x01\0\0\
\0\x73\x02\0\0\0\0\0\x0e\x11\0\0\0\x01\0\0\0\x89\x02\0\0\0\0\0\x0e\x11\0\0\0\
\x01\0\0\0\xa2\x02\0\0\0\0\0\x0e\x0e\0\0\0\x01\0\0\0\xaf\x02\0\0\0\0\0\x0e\x0e\
\0\0\0\x01\0\0\0\xbd\x02\0\0\0\0\0\x0e\x11\0\0\0\x01\0\0\0\xca\x02\0\0\0\0\0\
\x0e\x11\0\0\0\x01\0\0\0\x2b\x0a\0\0\x14\0\0\x0f\x9c\0\0\0\x0d\0\0\0\0\0\0\0\
\x01\0\0\0\x0f\0\0\0\x08\0\0\0\x08\0\0\0\x13\0\0\0\x10\0\0\0\x04\0\0\0\x17\0\0\
\0\x18\0\0\0\x08\0\0\0\x1a\0\0\0\x20\0\0\0\x08\0\0\0\x1d\0\0\0\x28\0\0\0\x04\0\
\0\0\x21\0\0\0\x30\0\0\0\x08\0\0\0\x22\0\0\0\x38\0\0\0\x08\0\0\0\x24\0\0\0\x40\
\0\0\0\x04\0\0\0\x26\0\0\0\x48\0\0\0\x08\0\0\0\x27\0\0\0\x50\0\0\0\x08\0\0\0\
\x29\0\0\0\x58\0\0\0\x04\0\0\0\x2b\0\0\0\x60\0\0\0\x08\0\0\0\x2c\0\0\0\x68\0\0\
\0\x08\0\0\0\x2e\0\0\0\x70\0\0\0\x04\0\0\0\x30\0\0\0\x78\0\0\0\x08\0\0\0\x31\0\
\0\0\x80\0\0\0\x08\0\0\0\x34\0\0\0\x88\0\0\0\x04\0\0\0\x37\0\0\0\x90\0\0\0\x08\
\0\0\0\x39\0\0\0\x98\0\0\0\x04\0\0\0\x31\x0a\0\0\x14\0\0\x0f\x94\0\0\0\x10\0\0\
\0\0\0\0\0\x08\0\0\0\x14\0\0\0\x08\0\0\0\x04\0\0\0\x15\0\0\0\x10\0\0\0\x08\0\0\
\0\x16\0\0\0\x18\0\0\0\x08\0\0\0\x1b\0\0\0\x20\0\0\0\x08\0\0\0\x1e\0\0\0\x28\0\
\0\0\x04\0\0\0\x1f\0\0\0\x30\0\0\0\x08\0\0\0\x20\0\0\0\x38\0\0\0\x08\0\0\0\x23\
\0\0\0\x40\0\0\0\x08\0\0\0\x25\0\0\0\x48\0\0\0\x04\0\0\0\x28\0\0\0\x50\0\0\0\
\x08\0\0\0\x2a\0\0\0\x58\0\0\0\x04\0\0\0\x2d\0\0\0\x60\0\0\0\x08\0\0\0\x2f\0\0\
\0\x68\0\0\0\x04\0\0\0\x32\0\0\0\x70\0\0\0\x08\0\0\0\x33\0\0\0\x78\0\0\0\x08\0\
\0\0\x35\0\0\0\x80\0\0\0\x04\0\0\0\x36\0\0\0\x84\0\0\0\x04\0\0\0\x38\0\0\0\x88\
\0\0\0\x08\0\0\0\x3a\0\0\0\x90\0\0\0\x04\0\0\0\0\x6c\x6f\x6e\x67\x20\x6c\x6f\
\x6e\x67\x20\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x69\x6e\x74\0\x63\x74\x78\0\
\x69\x6e\x74\0\x61\x64\x64\0\x73\x75\x62\0\x61\x6e\x64\0\x6f\x72\0\x78\x6f\x72\
\0\x63\x6d\x70\x78\x63\x68\x67\0\x78\x63\x68\x67\0\x5f\x42\x6f\x6f\x6c\0\x73\
\x6b\x69\x70\x5f\x74\x65\x73\x74\x73\0\x5f\x5f\x75\x36\x34\0\x61\x64\x64\x36\
\x34\x5f\x76\x61\x6c\x75\x65\0\x61\x64\x64\x36\x34\x5f\x72\x65\x73\x75\x6c\x74\
\0\x5f\x5f\x75\x33\x32\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x69\x6e\x74\0\x61\
\x64\x64\x33\x32\x5f\x76\x61\x6c\x75\x65\0\x61\x64\x64\x33\x32\x5f\x72\x65\x73\
\x75\x6c\x74\0\x61\x64\x64\x5f\x73\x74\x61\x63\x6b\x5f\x76\x61\x6c\x75\x65\x5f\
\x63\x6f\x70\x79\0\x61\x64\x64\x5f\x73\x74\x61\x63\x6b\x5f\x72\x65\x73\x75\x6c\
\x74\0\x61\x64\x64\x5f\x6e\x6f\x72\x65\x74\x75\x72\x6e\x5f\x76\x61\x6c\x75\x65\
\0\x5f\x5f\x73\x36\x34\0\x6c\x6f\x6e\x67\x20\x6c\x6f\x6e\x67\x20\x69\x6e\x74\0\
\x73\x75\x62\x36\x34\x5f\x76\x61\x6c\x75\x65\0\x73\x75\x62\x36\x34\x5f\x72\x65\
\x73\x75\x6c\x74\0\x5f\x5f\x73\x33\x32\0\x73\x75\x62\x33\x32\x5f\x76\x61\x6c\
\x75\x65\0\x73\x75\x62\x33\x32\x5f\x72\x65\x73\x75\x6c\x74\0\x73\x75\x62\x5f\
\x73\x74\x61\x63\x6b\x5f\x76\x61\x6c\x75\x65\x5f\x63\x6f\x70\x79\0\x73\x75\x62\
\x5f\x73\x74\x61\x63\x6b\x5f\x72\x65\x73\x75\x6c\x74\0\x73\x75\x62\x5f\x6e\x6f\
\x72\x65\x74\x75\x72\x6e\x5f\x76\x61\x6c\x75\x65\0\x61\x6e\x64\x36\x34\x5f\x76\
\x61\x6c\x75\x65\0\x61\x6e\x64\x36\x34\x5f\x72\x65\x73\x75\x6c\x74\0\x61\x6e\
\x64\x33\x32\x5f\x76\x61\x6c\x75\x65\0\x61\x6e\x64\x33\x32\x5f\x72\x65\x73\x75\
\x6c\x74\0\x61\x6e\x64\x5f\x6e\x6f\x72\x65\x74\x75\x72\x6e\x5f\x76\x61\x6c\x75\
\x65\0\x6f\x72\x36\x34\x5f\x76\x61\x6c\x75\x65\0\x6f\x72\x36\x34\x5f\x72\x65\
\x73\x75\x6c\x74\0\x6f\x72\x33\x32\x5f\x76\x61\x6c\x75\x65\0\x6f\x72\x33\x32\
\x5f\x72\x65\x73\x75\x6c\x74\0\x6f\x72\x5f\x6e\x6f\x72\x65\x74\x75\x72\x6e\x5f\
\x76\x61\x6c\x75\x65\0\x78\x6f\x72\x36\x34\x5f\x76\x61\x6c\x75\x65\0\x78\x6f\
\x72\x36\x34\x5f\x72\x65\x73\x75\x6c\x74\0\x78\x6f\x72\x33\x32\x5f\x76\x61\x6c\
\x75\x65\0\x78\x6f\x72\x33\x32\x5f\x72\x65\x73\x75\x6c\x74\0\x78\x6f\x72\x5f\
\x6e\x6f\x72\x65\x74\x75\x72\x6e\x5f\x76\x61\x6c\x75\x65\0\x63\x6d\x70\x78\x63\
\x68\x67\x36\x34\x5f\x76\x61\x6c\x75\x65\0\x63\x6d\x70\x78\x63\x68\x67\x36\x34\
\x5f\x72\x65\x73\x75\x6c\x74\x5f\x66\x61\x69\x6c\0\x63\x6d\x70\x78\x63\x68\x67\
\x36\x34\x5f\x72\x65\x73\x75\x6c\x74\x5f\x73\x75\x63\x63\x65\x65\x64\0\x63\x6d\
\x70\x78\x63\x68\x67\x33\x32\x5f\x76\x61\x6c\x75\x65\0\x63\x6d\x70\x78\x63\x68\
\x67\x33\x32\x5f\x72\x65\x73\x75\x6c\x74\x5f\x66\x61\x69\x6c\0\x63\x6d\x70\x78\
\x63\x68\x67\x33\x32\x5f\x72\x65\x73\x75\x6c\x74\x5f\x73\x75\x63\x63\x65\x65\
\x64\0\x78\x63\x68\x67\x36\x34\x5f\x76\x61\x6c\x75\x65\0\x78\x63\x68\x67\x36\
\x34\x5f\x72\x65\x73\x75\x6c\x74\0\x78\x63\x68\x67\x33\x32\x5f\x76\x61\x6c\x75\
\x65\0\x78\x63\x68\x67\x33\x32\x5f\x72\x65\x73\x75\x6c\x74\0\x2f\x62\x75\x69\
\x6c\x64\x64\x69\x72\x2f\x62\x75\x69\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\x6b\
\x65\x72\x6e\x65\x6c\x2d\x34\x2e\x31\x38\x2e\x30\x2d\x33\x35\x38\x2e\x65\x6c\
\x38\x2f\x6c\x69\x6e\x75\x78\x2d\x34\x2e\x31\x38\x2e\x30\x2d\x33\x35\x38\x2e\
\x65\x6c\x38\x2e\x70\x70\x63\x36\x34\x6c\x65\x2f\x74\x6f\x6f\x6c\x73\x2f\x74\
\x65\x73\x74\x69\x6e\x67\x2f\x73\x65\x6c\x66\x74\x65\x73\x74\x73\x2f\x62\x70\
\x66\x2f\x70\x72\x6f\x67\x73\x2f\x61\x74\x6f\x6d\x69\x63\x73\x2e\x63\0\x69\x6e\
\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x61\x64\x64\x2c\x20\x69\x6e\x74\
\x20\x61\x29\0\x09\x5f\x5f\x75\x36\x34\x20\x61\x64\x64\x5f\x73\x74\x61\x63\x6b\
\x5f\x76\x61\x6c\x75\x65\x20\x3d\x20\x31\x3b\0\x09\x61\x64\x64\x36\x34\x5f\x72\
\x65\x73\x75\x6c\x74\x20\x3d\x20\x5f\x5f\x73\x79\x6e\x63\x5f\x66\x65\x74\x63\
\x68\x5f\x61\x6e\x64\x5f\x61\x64\x64\x28\x26\x61\x64\x64\x36\x34\x5f\x76\x61\
\x6c\x75\x65\x2c\x20\x32\x29\x3b\0\x09\x61\x64\x64\x33\x32\x5f\x72\x65\x73\x75\
\x6c\x74\x20\x3d\x20\x5f\x5f\x73\x79\x6e\x63\x5f\x66\x65\x74\x63\x68\x5f\x61\
\x6e\x64\x5f\x61\x64\x64\x28\x26\x61\x64\x64\x33\x32\x5f\x76\x61\x6c\x75\x65\
\x2c\x20\x32\x29\x3b\0\x09\x61\x64\x64\x5f\x73\x74\x61\x63\x6b\x5f\x72\x65\x73\
\x75\x6c\x74\x20\x3d\x20\x5f\x5f\x73\x79\x6e\x63\x5f\x66\x65\x74\x63\x68\x5f\
\x61\x6e\x64\x5f\x61\x64\x64\x28\x26\x61\x64\x64\x5f\x73\x74\x61\x63\x6b\x5f\
\x76\x61\x6c\x75\x65\x2c\x20\x32\x29\x3b\0\x09\x61\x64\x64\x5f\x73\x74\x61\x63\
\x6b\x5f\x76\x61\x6c\x75\x65\x5f\x63\x6f\x70\x79\x20\x3d\x20\x61\x64\x64\x5f\
\x73\x74\x61\x63\x6b\x5f\x76\x61\x6c\x75\x65\x3b\0\x09\x5f\x5f\x73\x79\x6e\x63\
\x5f\x66\x65\x74\x63\x68\x5f\x61\x6e\x64\x5f\x61\x64\x64\x28\x26\x61\x64\x64\
\x5f\x6e\x6f\x72\x65\x74\x75\x72\x6e\x5f\x76\x61\x6c\x75\x65\x2c\x20\x32\x29\
\x3b\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x73\x75\x62\x2c\x20\
\x69\x6e\x74\x20\x61\x29\0\x09\x5f\x5f\x75\x36\x34\x20\x73\x75\x62\x5f\x73\x74\
\x61\x63\x6b\x5f\x76\x61\x6c\x75\x65\x20\x3d\x20\x31\x3b\0\x09\x73\x75\x62\x36\
\x34\x5f\x72\x65\x73\x75\x6c\x74\x20\x3d\x20\x5f\x5f\x73\x79\x6e\x63\x5f\x66\
\x65\x74\x63\x68\x5f\x61\x6e\x64\x5f\x73\x75\x62\x28\x26\x73\x75\x62\x36\x34\
\x5f\x76\x61\x6c\x75\x65\x2c\x20\x32\x29\x3b\0\x09\x73\x75\x62\x33\x32\x5f\x72\
\x65\x73\x75\x6c\x74\x20\x3d\x20\x5f\x5f\x73\x79\x6e\x63\x5f\x66\x65\x74\x63\
\x68\x5f\x61\x6e\x64\x5f\x73\x75\x62\x28\x26\x73\x75\x62\x33\x32\x5f\x76\x61\
\x6c\x75\x65\x2c\x20\x32\x29\x3b\0\x09\x73\x75\x62\x5f\x73\x74\x61\x63\x6b\x5f\
\x72\x65\x73\x75\x6c\x74\x20\x3d\x20\x5f\x5f\x73\x79\x6e\x63\x5f\x66\x65\x74\
\x63\x68\x5f\x61\x6e\x64\x5f\x73\x75\x62\x28\x26\x73\x75\x62\x5f\x73\x74\x61\
\x63\x6b\x5f\x76\x61\x6c\x75\x65\x2c\x20\x32\x29\x3b\0\x09\x73\x75\x62\x5f\x73\
\x74\x61\x63\x6b\x5f\x76\x61\x6c\x75\x65\x5f\x63\x6f\x70\x79\x20\x3d\x20\x73\
\x75\x62\x5f\x73\x74\x61\x63\x6b\x5f\x76\x61\x6c\x75\x65\x3b\0\x09\x5f\x5f\x73\
\x79\x6e\x63\x5f\x66\x65\x74\x63\x68\x5f\x61\x6e\x64\x5f\x73\x75\x62\x28\x26\
\x73\x75\x62\x5f\x6e\x6f\x72\x65\x74\x75\x72\x6e\x5f\x76\x61\x6c\x75\x65\x2c\
\x20\x32\x29\x3b\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x61\x6e\
\x64\x2c\x20\x69\x6e\x74\x20\x61\x29\0\x09\x61\x6e\x64\x36\x34\x5f\x72\x65\x73\
\x75\x6c\x74\x20\x3d\x20\x5f\x5f\x73\x79\x6e\x63\x5f\x66\x65\x74\x63\x68\x5f\
\x61\x6e\x64\x5f\x61\x6e\x64\x28\x26\x61\x6e\x64\x36\x34\x5f\x76\x61\x6c\x75\
\x65\x2c\x20\x30\x78\x30\x31\x31\x75\x6c\x6c\x20\x3c\x3c\x20\x33\x32\x29\x3b\0\
\x09\x61\x6e\x64\x33\x32\x5f\x72\x65\x73\x75\x6c\x74\x20\x3d\x20\x5f\x5f\x73\
\x79\x6e\x63\x5f\x66\x65\x74\x63\x68\x5f\x61\x6e\x64\x5f\x61\x6e\x64\x28\x26\
\x61\x6e\x64\x33\x32\x5f\x76\x61\x6c\x75\x65\x2c\x20\x30\x78\x30\x31\x31\x29\
\x3b\0\x09\x5f\x5f\x73\x79\x6e\x63\x5f\x66\x65\x74\x63\x68\x5f\x61\x6e\x64\x5f\
\x61\x6e\x64\x28\x26\x61\x6e\x64\x5f\x6e\x6f\x72\x65\x74\x75\x72\x6e\x5f\x76\
\x61\x6c\x75\x65\x2c\x20\x30\x78\x30\x31\x31\x75\x6c\x6c\x20\x3c\x3c\x20\x33\
\x32\x29\x3b\0\x69\x6e\x74\x20\x42\x50\x46\x5f\x50\x52\x4f\x47\x28\x6f\x72\x2c\
\x20\x69\x6e\x74\x20\x61\x29\0\x09\x6f\x72\x36\x34\x5f\x72\x65\x73\x75\x6c\x74\
\x20\x3d\x20\x5f\x5f\x73\x79\x6e\x63\x5f\x66\x65\x74\x63\x68\x5f\x61\x6e\x64\
\x5f\x6f\x72\x28\x26\x6f\x72\x36\x34\x5f\x76\x61\x6c\x75\x65\x2c\x20\x30\x78\
\x30\x31\x31\x75\x6c\x6c\x20\x3c\x3c\x20\x33\x32\x29\x3b\0\x09\x6f\x72\x33\x32\
\x5f\x72\x65\x73\x75\x6c\x74\x20\x3d\x20\x5f\x5f\x73\x79\x6e\x63\x5f\x66\x65\
\x74\x63\x68\x5f\x61\x6e\x64\x5f\x6f\x72\x28\x26\x6f\x72\x33\x32\x5f\x76\x61\
\x6c\x75\x65\x2c\x20\x30\x78\x30\x31\x31\x29\x3b\0\x09\x5f\x5f\x73\x79\x6e\x63\
\x5f\x66\x65\x74\x63\x68\x5f\x61\x6e\x64\x5f\x6f\x72\x28\x26\x6f\x72\x5f\x6e\
\x6f\x72\x65\x74\x75\x72\x6e\x5f\x76\x61\x6c\x75\x65\x2c\x20\x30\x78\x30\x31\
\x31\x75\x6c\x6c\x20\x3c\x3c\x20\x33\x32\x29\x3b\0\x69\x6e\x74\x20\x42\x50\x46\
\x5f\x50\x52\x4f\x47\x28\x78\x6f\x72\x2c\x20\x69\x6e\x74\x20\x61\x29\0\x09\x78\
\x6f\x72\x36\x34\x5f\x72\x65\x73\x75\x6c\x74\x20\x3d\x20\x5f\x5f\x73\x79\x6e\
\x63\x5f\x66\x65\x74\x63\x68\x5f\x61\x6e\x64\x5f\x78\x6f\x72\x28\x26\x78\x6f\
\x72\x36\x34\x5f\x76\x61\x6c\x75\x65\x2c\x20\x30\x78\x30\x31\x31\x75\x6c\x6c\
\x20\x3c\x3c\x20\x33\x32\x29\x3b\0\x09\x78\x6f\x72\x33\x32\x5f\x72\x65\x73\x75\
\x6c\x74\x20\x3d\x20\x5f\x5f\x73\x79\x6e\x63\x5f\x66\x65\x74\x63\x68\x5f\x61\
\x6e\x64\x5f\x78\x6f\x72\x28\x26\x78\x6f\x72\x33\x32\x5f\x76\x61\x6c\x75\x65\
\x2c\x20\x30\x78\x30\x31\x31\x29\x3b\0\x09\x5f\x5f\x73\x79\x6e\x63\x5f\x66\x65\
\x74\x63\x68\x5f\x61\x6e\x64\x5f\x78\x6f\x72\x28\x26\x78\x6f\x72\x5f\x6e\x6f\
\x72\x65\x74\x75\x72\x6e\x5f\x76\x61\x6c\x75\x65\x2c\x20\x30\x78\x30\x31\x31\
\x75\x6c\x6c\x20\x3c\x3c\x20\x33\x32\x29\x3b\0\x69\x6e\x74\x20\x42\x50\x46\x5f\
\x50\x52\x4f\x47\x28\x63\x6d\x70\x78\x63\x68\x67\x2c\x20\x69\x6e\x74\x20\x61\
\x29\0\x09\x63\x6d\x70\x78\x63\x68\x67\x36\x34\x5f\x72\x65\x73\x75\x6c\x74\x5f\
\x66\x61\x69\x6c\x20\x3d\x20\x5f\x5f\x73\x79\x6e\x63\x5f\x76\x61\x6c\x5f\x63\
\x6f\x6d\x70\x61\x72\x65\x5f\x61\x6e\x64\x5f\x73\x77\x61\x70\x28\x26\x63\x6d\
\x70\x78\x63\x68\x67\x36\x34\x5f\x76\x61\x6c\x75\x65\x2c\x20\x30\x2c\x20\x33\
\x29\x3b\0\x09\x63\x6d\x70\x78\x63\x68\x67\x36\x34\x5f\x72\x65\x73\x75\x6c\x74\
\x5f\x73\x75\x63\x63\x65\x65\x64\x20\x3d\x20\x5f\x5f\x73\x79\x6e\x63\x5f\x76\
\x61\x6c\x5f\x63\x6f\x6d\x70\x61\x72\x65\x5f\x61\x6e\x64\x5f\x73\x77\x61\x70\
\x28\x26\x63\x6d\x70\x78\x63\x68\x67\x36\x34\x5f\x76\x61\x6c\x75\x65\x2c\x20\
\x31\x2c\x20\x32\x29\x3b\0\x09\x63\x6d\x70\x78\x63\x68\x67\x33\x32\x5f\x72\x65\
\x73\x75\x6c\x74\x5f\x66\x61\x69\x6c\x20\x3d\x20\x5f\x5f\x73\x79\x6e\x63\x5f\
\x76\x61\x6c\x5f\x63\x6f\x6d\x70\x61\x72\x65\x5f\x61\x6e\x64\x5f\x73\x77\x61\
\x70\x28\x26\x63\x6d\x70\x78\x63\x68\x67\x33\x32\x5f\x76\x61\x6c\x75\x65\x2c\
\x20\x30\x2c\x20\x33\x29\x3b\0\x09\x63\x6d\x70\x78\x63\x68\x67\x33\x32\x5f\x72\
\x65\x73\x75\x6c\x74\x5f\x73\x75\x63\x63\x65\x65\x64\x20\x3d\x20\x5f\x5f\x73\
\x79\x6e\x63\x5f\x76\x61\x6c\x5f\x63\x6f\x6d\x70\x61\x72\x65\x5f\x61\x6e\x64\
\x5f\x73\x77\x61\x70\x28\x26\x63\x6d\x70\x78\x63\x68\x67\x33\x32\x5f\x76\x61\
\x6c\x75\x65\x2c\x20\x31\x2c\x20\x32\x29\x3b\0\x69\x6e\x74\x20\x42\x50\x46\x5f\
\x50\x52\x4f\x47\x28\x78\x63\x68\x67\x2c\x20\x69\x6e\x74\x20\x61\x29\0\x09\x78\
\x63\x68\x67\x36\x34\x5f\x72\x65\x73\x75\x6c\x74\x20\x3d\x20\x5f\x5f\x73\x79\
\x6e\x63\x5f\x6c\x6f\x63\x6b\x5f\x74\x65\x73\x74\x5f\x61\x6e\x64\x5f\x73\x65\
\x74\x28\x26\x78\x63\x68\x67\x36\x34\x5f\x76\x61\x6c\x75\x65\x2c\x20\x76\x61\
\x6c\x36\x34\x29\x3b\0\x09\x78\x63\x68\x67\x33\x32\x5f\x72\x65\x73\x75\x6c\x74\
\x20\x3d\x20\x5f\x5f\x73\x79\x6e\x63\x5f\x6c\x6f\x63\x6b\x5f\x74\x65\x73\x74\
\x5f\x61\x6e\x64\x5f\x73\x65\x74\x28\x26\x78\x63\x68\x67\x33\x32\x5f\x76\x61\
\x6c\x75\x65\x2c\x20\x76\x61\x6c\x33\x32\x29\x3b\0\x2e\x64\x61\x74\x61\0\x2e\
\x62\x73\x73\0\x66\x65\x6e\x74\x72\x79\x2f\x62\x70\x66\x5f\x66\x65\x6e\x74\x72\
\x79\x5f\x74\x65\x73\x74\x31\0\0\0\0\0\0\0\x9f\xeb\x01\0\x20\0\0\0\0\0\0\0\x44\
\0\0\0\x44\0\0\0\xfc\x03\0\0\x40\x04\0\0\0\0\0\0\x08\0\0\0\x36\x0a\0\0\x07\0\0\
\0\0\0\0\0\x05\0\0\0\xf8\0\0\0\x06\0\0\0\0\x02\0\0\x07\0\0\0\xb0\x02\0\0\x08\0\
\0\0\x60\x03\0\0\x09\0\0\0\x10\x04\0\0\x0a\0\0\0\0\x05\0\0\x0b\0\0\0\x10\0\0\0\
\x36\x0a\0\0\x3f\0\0\0\0\0\0\0\xd8\x02\0\0\x4d\x03\0\0\0\x58\0\0\x08\0\0\0\xd8\
\x02\0\0\x66\x03\0\0\x08\x64\0\0\x18\0\0\0\xd8\x02\0\0\x82\x03\0\0\x11\x6c\0\0\
\x38\0\0\0\xd8\x02\0\0\x82\x03\0\0\x0f\x6c\0\0\x58\0\0\0\xd8\x02\0\0\xb9\x03\0\
\0\x11\x70\0\0\x70\0\0\0\xd8\x02\0\0\xb9\x03\0\0\x0f\x70\0\0\x88\0\0\0\xd8\x02\
\0\0\xf0\x03\0\0\x15\x74\0\0\x98\0\0\0\xd8\x02\0\0\xf0\x03\0\0\x13\x74\0\0\xb0\
\0\0\0\xd8\x02\0\0\x2f\x04\0\0\x17\x78\0\0\xc0\0\0\0\xd8\x02\0\0\x2f\x04\0\0\
\x19\x78\0\0\xc8\0\0\0\xd8\x02\0\0\x2f\x04\0\0\x17\x78\0\0\xd0\0\0\0\xd8\x02\0\
\0\x58\x04\0\0\x02\x7c\0\0\xe8\0\0\0\xd8\x02\0\0\x4d\x03\0\0\x05\x58\0\0\xf8\0\
\0\0\xd8\x02\0\0\x87\x04\0\0\0\xb8\0\0\0\x01\0\0\xd8\x02\0\0\xa0\x04\0\0\x08\
\xc4\0\0\x10\x01\0\0\xd8\x02\0\0\xbc\x04\0\0\x11\xcc\0\0\x38\x01\0\0\xd8\x02\0\
\0\xbc\x04\0\0\x0f\xcc\0\0\x58\x01\0\0\xd8\x02\0\0\xf3\x04\0\0\x11\xd0\0\0\x78\
\x01\0\0\xd8\x02\0\0\xf3\x04\0\0\x0f\xd0\0\0\x90\x01\0\0\xd8\x02\0\0\x2a\x05\0\
\0\x15\xd4\0\0\xa0\x01\0\0\xd8\x02\0\0\x2a\x05\0\0\x13\xd4\0\0\xb8\x01\0\0\xd8\
\x02\0\0\x69\x05\0\0\x17\xd8\0\0\xc8\x01\0\0\xd8\x02\0\0\x69\x05\0\0\x19\xd8\0\
\0\xd0\x01\0\0\xd8\x02\0\0\x69\x05\0\0\x17\xd8\0\0\xd8\x01\0\0\xd8\x02\0\0\x92\
\x05\0\0\x02\xdc\0\0\xf0\x01\0\0\xd8\x02\0\0\x87\x04\0\0\x05\xb8\0\0\0\x02\0\0\
\xd8\x02\0\0\xc1\x05\0\0\0\x10\x01\0\x10\x02\0\0\xd8\x02\0\0\xda\x05\0\0\x11\
\x20\x01\0\x38\x02\0\0\xd8\x02\0\0\xda\x05\0\0\x0f\x20\x01\0\x58\x02\0\0\xd8\
\x02\0\0\x1e\x06\0\0\x11\x24\x01\0\x70\x02\0\0\xd8\x02\0\0\x1e\x06\0\0\x0f\x24\
\x01\0\x88\x02\0\0\xd8\x02\0\0\x59\x06\0\0\x02\x28\x01\0\xa0\x02\0\0\xd8\x02\0\
\0\xc1\x05\0\0\x05\x10\x01\0\xb0\x02\0\0\xd8\x02\0\0\x95\x06\0\0\0\x5c\x01\0\
\xc0\x02\0\0\xd8\x02\0\0\xad\x06\0\0\x10\x68\x01\0\xe8\x02\0\0\xd8\x02\0\0\xad\
\x06\0\0\x0e\x68\x01\0\x08\x03\0\0\xd8\x02\0\0\xee\x06\0\0\x10\x6c\x01\0\x20\
\x03\0\0\xd8\x02\0\0\xee\x06\0\0\x0e\x6c\x01\0\x38\x03\0\0\xd8\x02\0\0\x26\x07\
\0\0\x02\x70\x01\0\x50\x03\0\0\xd8\x02\0\0\x95\x06\0\0\x05\x5c\x01\0\x60\x03\0\
\0\xd8\x02\0\0\x60\x07\0\0\0\xa4\x01\0\x70\x03\0\0\xd8\x02\0\0\x79\x07\0\0\x11\
\xb0\x01\0\x98\x03\0\0\xd8\x02\0\0\x79\x07\0\0\x0f\xb0\x01\0\xb8\x03\0\0\xd8\
\x02\0\0\xbd\x07\0\0\x11\xb4\x01\0\xd0\x03\0\0\xd8\x02\0\0\xbd\x07\0\0\x0f\xb4\
\x01\0\xe8\x03\0\0\xd8\x02\0\0\xf8\x07\0\0\x02\xb8\x01\0\0\x04\0\0\xd8\x02\0\0\
\x60\x07\0\0\x05\xa4\x01\0\x10\x04\0\0\xd8\x02\0\0\x34\x08\0\0\0\xf0\x01\0\x18\
\x04\0\0\xd8\x02\0\0\x51\x08\0\0\x1a\xfc\x01\0\x38\x04\0\0\xd8\x02\0\0\x51\x08\
\0\0\x18\xfc\x01\0\x58\x04\0\0\xd8\x02\0\0\x9f\x08\0\0\x1d\0\x02\0\x68\x04\0\0\
\xd8\x02\0\0\x9f\x08\0\0\x1b\0\x02\0\x88\x04\0\0\xd8\x02\0\0\xf0\x08\0\0\x1a\
\x08\x02\0\xa8\x04\0\0\xd8\x02\0\0\xf0\x08\0\0\x18\x08\x02\0\xc8\x04\0\0\xd8\
\x02\0\0\x3e\x09\0\0\x1d\x0c\x02\0\xd8\x04\0\0\xd8\x02\0\0\x3e\x09\0\0\x1b\x0c\
\x02\0\xf0\x04\0\0\xd8\x02\0\0\x34\x08\0\0\x05\xf0\x01\0\0\x05\0\0\xd8\x02\0\0\
\x8f\x09\0\0\0\x3c\x02\0\x08\x05\0\0\xd8\x02\0\0\xa9\x09\0\0\x12\x54\x02\0\x20\
\x05\0\0\xd8\x02\0\0\xa9\x09\0\0\x10\x54\x02\0\x40\x05\0\0\xd8\x02\0\0\xea\x09\
\0\0\x12\x58\x02\0\x58\x05\0\0\xd8\x02\0\0\xea\x09\0\0\x10\x58\x02\0\x70\x05\0\
\0\xd8\x02\0\0\x8f\x09\0\0\x05\x3c\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x01\0\0\0\x03\0\0\0\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\
\0\0\0\xe7\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x09\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x28\x03\0\0\0\0\0\0\xb0\
\x04\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x18\0\0\0\0\0\0\0\x11\0\0\
\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xd8\x07\0\0\0\0\0\0\x80\x05\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x29\0\0\0\x01\0\0\0\
\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x58\x0d\0\0\0\0\0\0\x9c\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x2f\0\0\0\x08\0\0\0\x03\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\xf8\x0d\0\0\0\0\0\0\x94\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xbd\x02\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\xf8\x0d\0\0\0\0\0\0\x70\x02\0\0\0\0\0\0\x02\0\0\0\x03\0\0\0\x08\0\0\0\0\
\0\0\0\x10\0\0\0\0\0\0\0\xd9\x02\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x68\x10\0\0\0\0\0\0\xd2\x0f\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\xde\x02\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\x20\0\0\
\0\0\0\0\x60\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0";

	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return -1;
}

#endif /* __ATOMICS_SKEL_H__ */
